@@ -1,5 +1,5 @@
 package Test::Inter;
-# Copyright (c) 2010-2011 Sullivan Beck. All rights reserved.
+# Copyright (c) 2010-2019 Sullivan Beck. All rights reserved.
 # This program is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 
@@ -13,7 +13,7 @@ use File::Basename;
 use IO::File;
 
 our($VERSION);
-$VERSION = '1.04';
+$VERSION = '1.08';
 
 ###############################################################################
 # BASE METHODS
@@ -51,6 +51,8 @@ sub new {
                'mode'     => 'test', # mode to run script in
                'width'    => 80,     # width of terminal
                'features' => {},     # a list of available features
+               'use_lib'  => 'on',   # whether to run 'use lib' when loading
+                                     # this module
 
                'skipall'  => '',     # the reason for skipping all
                                      # remaining tests
@@ -127,9 +129,25 @@ sub new {
    $$self{'testdir'} = $TDIR;
    $$self{'libdir'}  = \@LIBDIR;
 
+   $self->use_lib();
+
    return $self;
 }
 
+sub use_lib {
+   my($self,$val) = @_;
+   if (defined $val) {
+      $$self{'use_lib'} = $val;
+      return;
+   }
+
+   if ($$self{'use_lib'} eq 'on') {
+      foreach my $dir (@{ $$self{'libdir'} }) {
+         eval "use lib '$dir'";
+      }
+   }
+}
+
 sub testdir {
    my($self) = @_;
    return $$self{'testdir'};
@@ -857,7 +875,14 @@ sub file {
 
    # Output file and directory
 
-   $outputdir = $testdir  if (! $outputdir);
+   if (! $outputdir) {
+      if (-d $testdir  &&
+          -w $testdir) {
+         $outputdir = $testdir;
+      } else {
+         $outputdir = ".";
+      }
+   }
    if ($outputdir) {
       if (! -d $outputdir  ||
           ! -w $outputdir) {
@@ -901,7 +926,7 @@ sub file {
    my @exp = <$in>;
    $in->close();
    chomp(@exp);
-   unlink($output);
+   unlink($output)   if (! $ENV{'TI_NOCLEAN'});
 
    while (@out < @exp) {
       push(@out,'');
@@ -1406,24 +1431,42 @@ sub _skip {
          # Check for quoted
 
          ($err,$found,$match,@val) = $self->_parse_quoted($test,$EOT);
-         last  if ($found  ||  $err);
+         last  if ($err);
+         if ($found) {
+            # ''  remains ''
+            last;
+         }
 
          # Check for open
 
          ($err,$found,$match,@val) = $self->_parse_open_close($test,$EOT,$lparen,')');
-         last  if ($found  ||  $err);
+         last  if ($err);
+         if ($found) {
+            # ()  is an empty list
+            if (@val == 1  &&  $val[0] eq '') {
+               @val = ();
+            }
+            last;
+         }
 
          ($err,$found,$match,@val) = $self->_parse_open_close($test,$EOT,$lbrack,']');
          last  if ($err);
          if ($found) {
-            @val = ( [@val] );
+            # []  is []
+            if (@val == 1  &&  $val[0] eq '') {
+               @val = ([]);
+            } else {
+               @val = ( [@val] );
+            }
             last;
          }
 
          ($err,$found,$match,@val) = $self->_parse_open_close($test,$EOT,$lbrace,'}');
          last  if ($err);
          if ($found) {
-            if (@val % 2 == 0) {
+            if (@val == 1  &&  $val[0] eq '') {
+               @val = ( {} );
+            } elsif (@val % 2 == 0) {
                # Even number of elements
                @val = ( {@val} );
             } elsif (! defined $val[$#val]  ||
